@@ -24,6 +24,7 @@ static unsigned char *FImage;
 
 int FgCycNumCols  = FGCYC_NUMCOL_DEFVAL;
 int FgGradBarSize = FGGRAD_BARSIZE_DEFVAL;
+int EffectSteps = 0;                   /* no back/forth stepping */
 
 /* draw the main thing... the FG one - no shadows and stuff */
 static _inline void DrawFG(void)
@@ -455,9 +456,9 @@ static void MakeZImageOutline(Zmethod direction)
     error(disp,mgc,"REPORT: Alloc pix1",True);
 
   /* main loop first time */
-  for(y=1 ; y < rel_h-1 ; y++)
+  for(y=Thickness+1 ; y < rel_h-Thickness-1 ; y++)
   {
-    for(x=1 ; x < rel_w-1 ; x++)
+    for(x=Thickness+1 ; x < rel_w-Thickness-1 ; x++)
     {
       if(direction==OUTWARDS)
       {
@@ -608,6 +609,8 @@ void DoBacklightEffect(void)
       cyc_inf[num_used_cyc].grad_num = gradnum;
       cyc_inf[num_used_cyc].only_first = False;
       cyc_inf[num_used_cyc].dir = cdir;
+      cyc_inf[num_used_cyc].dir_steps = EffectSteps;
+      cyc_inf[num_used_cyc].dir_count = 0;
       num_used_cyc++;
     }
   }
@@ -661,6 +664,8 @@ void DoFGGradEffect(void)
       cyc_inf[num_used_cyc].grad_num = FgGradGrad;
       cyc_inf[num_used_cyc].only_first = False;
       cyc_inf[num_used_cyc].dir = FgGradCycDir;
+      cyc_inf[num_used_cyc].dir_steps = EffectSteps;
+      cyc_inf[num_used_cyc].dir_count = 0;
       num_used_cyc++;
     }
   }
@@ -736,6 +741,8 @@ void DoFGPlasmaEffect(void)
       cyc_inf[num_used_cyc].grad_num = FgPlasmaGrad;
       cyc_inf[num_used_cyc].only_first = False;
       cyc_inf[num_used_cyc].dir = FgplCycDir;
+      cyc_inf[num_used_cyc].dir_steps = EffectSteps;
+      cyc_inf[num_used_cyc].dir_count = 0;
       num_used_cyc++;
     }
   }
@@ -1222,6 +1229,8 @@ void DrawIt(void)
       cyc_inf[num_used_cyc].grad_num = FgCycGrad;
       cyc_inf[num_used_cyc].only_first = True;
       cyc_inf[num_used_cyc].dir = CYC_FORWARD;
+      cyc_inf[num_used_cyc].dir_steps = EffectSteps;
+      cyc_inf[num_used_cyc].dir_count = 0;
       num_used_cyc++;
     }
     else
