@@ -85,6 +85,7 @@ static Resource XBres[]= {
   { BGC,	"bgFillColor",		"BgFillColor" },
   { BGGRAD,	"bgGrad",		"BgGrad" },
   { BGGRADREP,	"bgGradRepeat",		"BgGradRepeat" },
+  { BGGRADSTEPS,"bgGradSteps",		"BgGradSteps" },
   { AUTO_FILL,  "autoFillBg",		"AutoFillBg" },
   { BGFILL,	"bgFill",		"BgFill" },
   { BARSIZE,	"barSize",		"BarSize" },
@@ -119,6 +120,7 @@ static Resource XBres[]= {
   { CYCREV,	"reverseCycle",		"ReverseCycle"},
   { CYCFOR,	"forwardCycle",		"ForwardCycle"},
   { CYCSPEED,	"cycleSpeed",		"CycleSpeed" },
+  { EFFECTSTEPS,"effectSteps",		"EffectSteps" },
 
 /* plasma and ripple effects */
   { PLASMA_NCOL,"plasmaNumColors",	"PlasmaNumColors" },
@@ -155,6 +157,7 @@ static Resource XBres[]= {
   { XOFFS,	"defXOffset",		"DefOffset" },
   { YOFFS,	"defYOffset",		"DefOffset" },
   { LINGER,	"linger",		"Linger" },
+  { EXPOSE,	"expose",		"Expose" },
 
   { TERM,"","" }
 };
@@ -211,6 +214,7 @@ static XrmOptionDescRec opTable[] = {
   {"-bg",	".bgFillColor",   XrmoptionSepArg, (caddr_t) NULL},
   {"-bggrad",	".bgGrad",	  XrmoptionSepArg, (caddr_t) NULL},
   {"-bggradrep",".bgGradRepeat",  XrmoptionSepArg, (caddr_t) NULL},
+  {"-bgsteps",  ".bgGradSteps",   XrmoptionSepArg, (caddr_t) NULL},
   {"-autofill", ".autoFillBg",    XrmoptionNoArg,  (caddr_t) "True"},
   {"-noautofill",".autoFillBg",   XrmoptionNoArg,  (caddr_t) "False"},
   {"-bgfill",	".bgFill",	  XrmoptionNoArg,  (caddr_t) "True"},
@@ -254,6 +258,7 @@ static XrmOptionDescRec opTable[] = {
   {"-cycrev",	".reverseCycle",  XrmoptionSepArg, (caddr_t) NULL},
   {"-cycfor",	".forwardCycle",  XrmoptionSepArg, (caddr_t) NULL},
   {"-cycspeed",	".cycleSpeed",	  XrmoptionSepArg, (caddr_t) NULL},
+  {"-effectsteps",".effectSteps",  XrmoptionSepArg, (caddr_t) NULL},
 
 /* debugging and information options */
   {"-showerr",	".showErrors",	  XrmoptionNoArg,  (caddr_t) "True"},
@@ -269,6 +274,8 @@ static XrmOptionDescRec opTable[] = {
   {"-y",	".y",		  XrmoptionSepArg, (caddr_t) NULL},
   {"-linger",	".linger",	  XrmoptionNoArg,  (caddr_t) "True"},
   {"-nolinger",	".linger",	  XrmoptionNoArg,  (caddr_t) "False"},
+  {"-expose",	".expose",	  XrmoptionNoArg,  (caddr_t) "True"},
+  {"-noexpose",	".expose",	  XrmoptionNoArg,  (caddr_t) "False"},
 
 /* awkward but it's ok - a terminator entry */
   {"-XBtermin",	".XBtermin",	  XrmoptionNoArg,  (caddr_t) "XBtermin"}
@@ -318,6 +325,8 @@ static OptDesc optDesc[] = {
   {" ",		"           Example: If you selected -bggrad red,yellow,red and also",True},
   {" ",		"           use -bggradrep 2, then a -bgstyle TopDown would seem to",True},
   {" ",		"           go from red to yellow to red to yellow back to red",False},
+  {"-bgsteps",	"          Make the color-cycling of the background change its",True},
+  {" ",		"           every this number of steps",False},
   {"-autofill", "          When using a -bgstyle TopDown, LeftRight and the two",True},
   {" ",		"           diagonal fills, this will color the background using",True},
   {" ",		"           the color that is half-way along the gradient. This",True},
@@ -395,6 +404,8 @@ static OptDesc optDesc[] = {
   {" ",         "           very slow. A certain speed around 10-20 is usually",True}, 
   {" ",         "           the fastest. To make things seem faster, use less",True}, 
   {" ",         "           colors or -bggradrep for BG styles",False},
+  {"-effectsteps","          This makes the effects that can color-cycle change",True},
+  {" ",		"           the cycling direction every number of steps",False},
 
 /* plasma & ripple effects */
   {"-plncol",	"Numeric   Number of colors for the Plasma BG style",False},
@@ -447,6 +458,11 @@ static OptDesc optDesc[] = {
   {"-nolinger",	"          Do not leave a process with an open display. This",True}, 
   {" ",         "           option WILL NOT suppress leaving a process for the",True}, 
   {" ",         "           -glint and -cycle options",False},
+  {"-expose",	"          Make XBanner redraw areas that have become exposed on",True}, 
+  {" ",         "           the screen. This is great with the moving XDM-3D. It",True}, 
+  {" ",         "           also implies -linger!",False},
+  {"-noexpose",	"          If your resource file contains *expose: True and you",True}, 
+  {" ",         "           wish to disable it.",False},
 
   {NULL,NULL}
 };
@@ -468,7 +484,8 @@ static int ParseGrad(char *line)
       if(grad[i].Used==False)
         break;
     if(i==NUM_GRADS)
-      error(disp,mgc,"No avail. color gradient",True);
+      error(disp,XDefaultGC(disp,DefaultScreen(disp)),
+      	"No avail. color gradient",True);
     else
     {
       grad[i].Used = True;        /* mark it as used */
@@ -479,7 +496,7 @@ static int ParseGrad(char *line)
   else /* !is_grad_line() */
   {
     sprintf(errline,"Value '%s' is not a color grad",line);
-    error(disp,mgc,errline,True);
+    error(disp,XDefaultGC(disp,DefaultScreen(disp)),errline,True);
   }
   return -1;
 } /* ParseGrad */
@@ -774,6 +791,12 @@ static void ParseResources(void)
       /* now let's do something with it */
       switch(XBres[j].opt)
       {
+	case BGGRADSTEPS:
+	  BgGradSteps = atoi_bounds(line,True,0,False,0,"BgGradSteps must not be negative!");
+	  break;
+	case EFFECTSTEPS:
+	  EffectSteps = atoi_bounds(line,True,0,False,0,"EffectSteps must not be negative!");
+	  break;
 	case BGPIXFN:
 	  strcpy(BGPIXFNAME,line);
 	  break;
@@ -788,9 +811,10 @@ static void ParseResources(void)
 	  break;
 	case RIPPLES:
 	  num_ripples = atoi_bounds(line,True,1,False,0,"You must specify a positive number of ripples.");
+	  break;
 	case FGPL_GRAIN:
 	  FgPlasmaGrain = atof(line);
-	  if(Grain<=0.0)
+	  if(FgPlasmaGrain<=0.0)
 	  {
 	    fprintf(stderr,"%s: PlasmaCloud Graininess factor must be positive.\n",PRGCLASS);
 	    exit(1);
@@ -904,6 +928,9 @@ static void ParseResources(void)
 	case LINGER:
 	  DoBoolean(line,&XB_Linger);
           break;
+	case EXPOSE:
+	  DoBoolean(line,&XB_Expose);
+          break;
 #ifdef HAS_XPM
         case PX:
           px = atoi_bounds(line,True,0,True,sc_w,"Pixmap X position out of screen!");
@@ -1000,7 +1027,7 @@ static void ParseResources(void)
       } /* switch */
     } /* if(Xrm...==True) */
   } /* for i */
-  
+
   /* handle XBanner.Surround: <val> properly */
   if(SUR_MIN==SUR_MAX)
   {
@@ -1013,8 +1040,8 @@ static void ParseResources(void)
   parse_env(BANNER);	/* parse environment variables */
 
   /* miscellaneous checks... */
-  if(XB_ColorCycle != CYCNONE || XB_Glint == True)
-  /* we need to linger around for glints... */
+  if(XB_ColorCycle != CYCNONE || XB_Glint == True || XB_Expose == True)
+  /* we need to linger around for glints, color cycling and expose events */
     XB_Linger=True;
 
   /* warn about glint and color-cycling */
@@ -1055,6 +1082,10 @@ static void ParseResources(void)
     BANNER[1]='\0';
     effect = None;		/* no effect - faster		*/
     strcpy(FONTN,"fixed");	/* don't load a scalable font	*/
+    strcpy(FGCOLOR,"black");	/* ensures we find the colors   */
+    strcpy(SHDCOLOR,"black");
+    strcpy(LGHTCOLOR,"black");
+    strcpy(ULCOLOR,"black");
   }
 
 } /* ParseResources */
